Further capabilities in the library
===================================

This section shows some of the more intricate capabilities of the library.

Contents:

.. toctree::
   :maxdepth: 2

   classification_of_strategies.rst
   strategy_transformers.rst
   making_tournaments.rst
   reading_and_writing_interactions.rst
   using_the_cache.rst
